@@ -3,7 +3,7 @@ package DhMakePerl::Command::Packaging;
 use strict;
 use warnings;
 
-our $VERSION = '0.122';
+our $VERSION = '0.124';
 
 use feature 'switch';
 
@@ -48,6 +48,7 @@ use File::Spec::Functions qw(catfile catpath splitpath);
 use Text::Balanced qw(extract_quotelike);
 use Text::Wrap qw(fill);
 use User::pwent;
+use version;
 
 use constant debstdversion => '4.6.2';
 
@@ -233,6 +234,20 @@ sub set_package_name {
         $pkgname = Debian::Control::FromCPAN->module_name_to_pkg_name( $self->perlname );
     }
 
+    if ( $self->perlname =~ /^App-/ && !defined $self->cfg->packagename ) {
+        ( my $suggestion = $pkgname ) =~ s/^libapp-(.+)-perl$/$1/;
+        print "******\n";
+        print "NOTICE\n";
+        print "******\n";
+        print "You are packaging '"
+            . $self->perlname
+            . "', and by default dh-make-perl will use \n"
+            . "'$pkgname' as the name for the package.\n"
+            . "Maybe '$suggestion' might be a better name.\n"
+            . "In that case please pass '--packagename $suggestion' to dh-make-perl.\n";
+        print "******\n";
+    }
+
     $self->control->source->Source($pkgname)
         unless $self->control->source->Source;
 
@@ -376,7 +391,7 @@ sub extract_name_ver {
         #Version specified on command line trumps other versions
         $ver = $self->cfg->version
     } elsif ( $self->mod_cpan_version ) {
-        if ($self->mod_cpan_version != $ver) {
+        if (version->parse($self->mod_cpan_version) != version->parse($ver)) {
             die "Version ambiguity, cpan has ".$self->mod_cpan_version.", module has ".$ver.". Please specify version with --version.\n";
         }
     }
@@ -1687,7 +1702,7 @@ sub _file_w {
 
 =item Copyright (C) 2006 Frank Lichtenheld <djpig@debian.org>
 
-=item Copyright (C) 2007-2021, gregor herrmann <gregoa@debian.org>
+=item Copyright (C) 2007-2023, gregor herrmann <gregoa@debian.org>
 
 =item Copyright (C) 2007-2013 Damyan Ivanov <dmn@debian.org>
 
