@@ -2,7 +2,7 @@ package DhMakePerl::Command::make;
 
 use warnings;
 use strict;
-our $VERSION = '0.122';
+our $VERSION = '0.124';
 use 5.010;    # we use smart matching
 
 use base 'DhMakePerl::Command::Packaging';
@@ -297,7 +297,7 @@ sub setup_dir {
         $orig_pwd = $ENV{'PWD'};
 
         # Is the module a core module?
-       if ( is_core_module( $self->cfg->cpan ) ) {
+        if ( is_core_module( $self->cfg->cpan ) ) {
             die $self->cfg->cpan
             . " is a standard module. Will not build without --core-ok.\n"
                 unless $self->cfg->core_ok;
@@ -328,13 +328,17 @@ sub setup_dir {
         }
 
         $dist->get;     # <- here $ENV{'PWD'} gets set to $HOME/.cpan/build
+
         # only in case $orig_pwd was not previously set, fall back to the first existing working path
         # cf. MR!3 and #815390
         if ( ! defined ($orig_pwd) ) {
             $orig_pwd = $ENV{'PWD'};
         }
 
-        chdir $orig_pwd;   # so set it back
+        $ENV{'PWD'} = $orig_pwd;  # so set it back
+                                  # otherwise --recursive ends up in $HOME/.cpan/build
+        chdir $orig_pwd;          # and change back to it
+
         $dist->pretty_id =~ /^(.)(.)/;
         $tarball = $CPAN::Config->{'keep_source_where'} . "/authors/id/$1/$1$2/";
         # the file is under authors/id/A/AU/AUTHOR directory
@@ -465,7 +469,7 @@ sub install_package {
         $archspec = $arch;
     }
 
-    $debname = sprintf( "%s_%s-1_%s.deb", $self->pkgname, $self->version,
+    $debname = sprintf( "%s_%s_%s.deb", $self->pkgname, $self->pkgversion,
         $archspec );
 
     my $deb = $self->main_dir . "/../$debname";
